@@ -6,4 +6,6 @@ from .hfn import HighFrequencyNews
 from .quotes import Quotes
 from .intraday_tick_data import IntradayTickData
 from .ticker_last_event import TickerLastEvent
-from .corporate_events import CorporateEvents
\ No newline at end of file
+from .corporate_events import CorporateEvents
+from .company_data import CompanyData
+from .public_sources import PublicSources
\ No newline at end of file
